lcvtoolbox.core.schemas.projection.Polygon
==========================================

.. currentmodule:: lcvtoolbox.core.schemas.projection

.. autoclass:: Polygon
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:
   :special-members: __init__, __str__, __repr__

   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~Polygon.__init__
      ~Polygon.buffer
      ~Polygon.contains
      ~Polygon.contains_properly
      ~Polygon.covered_by
      ~Polygon.covers
      ~Polygon.crosses
      ~Polygon.difference
      ~Polygon.disjoint
      ~Polygon.distance
      ~Polygon.dwithin
      ~Polygon.equals
      ~Polygon.equals_exact
      ~Polygon.from_bounds
      ~Polygon.geometryType
      ~Polygon.hausdorff_distance
      ~Polygon.interpolate
      ~Polygon.intersection
      ~Polygon.intersects
      ~Polygon.line_interpolate_point
      ~Polygon.line_locate_point
      ~Polygon.normalize
      ~Polygon.overlaps
      ~Polygon.point_on_surface
      ~Polygon.project
      ~Polygon.relate
      ~Polygon.relate_pattern
      ~Polygon.representative_point
      ~Polygon.reverse
      ~Polygon.segmentize
      ~Polygon.simplify
      ~Polygon.svg
      ~Polygon.symmetric_difference
      ~Polygon.touches
      ~Polygon.union
      ~Polygon.within
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Polygon.area
      ~Polygon.boundary
      ~Polygon.bounds
      ~Polygon.centroid
      ~Polygon.convex_hull
      ~Polygon.coords
      ~Polygon.envelope
      ~Polygon.exterior
      ~Polygon.geom_type
      ~Polygon.has_m
      ~Polygon.has_z
      ~Polygon.interiors
      ~Polygon.is_closed
      ~Polygon.is_empty
      ~Polygon.is_ring
      ~Polygon.is_simple
      ~Polygon.is_valid
      ~Polygon.length
      ~Polygon.minimum_clearance
      ~Polygon.minimum_rotated_rectangle
      ~Polygon.oriented_envelope
      ~Polygon.type
      ~Polygon.wkb
      ~Polygon.wkb_hex
      ~Polygon.wkt
      ~Polygon.xy
   
   